@@ -14,7 +14,6 @@ use strict;
 use warnings;
 use utf8;
 use parent qw/Amon2/;
-our $VERSION='0.01';
 use 5.008001;
 
 __PACKAGE__->load_plugin(qw/DBI/);
@@ -29,6 +28,7 @@ sub setup_schema {
     open my $fh, '<:encoding(UTF-8)', $fname or die "$fname: $!";
     my $source = do { local $/; <$fh> };
 	for my $stmt (split /;/, $source) {
+        next unless $stmt =~ /\S/;
 		$dbh->do($stmt) or die $dbh->errstr();
 	}
 }
